# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: draft/protos/ydb_federated_query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v5.protos.annotations import sensitive_pb2 as protos_dot_annotations_dot_sensitive__pb2
from ydb._grpc.v5.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from ydb._grpc.v5.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v5.protos import ydb_value_pb2 as protos_dot_ydb__value__pb2
from ydb._grpc.v5.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&draft/protos/ydb_federated_query.proto\x12\x0e\x46\x65\x64\x65ratedQuery\x1a\"protos/annotations/sensitive.proto\x1a#protos/annotations/validation.proto\x1a\x1aprotos/ydb_operation.proto\x1a\x16protos/ydb_value.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"{\n\x03\x41\x63l\x12\x32\n\nvisibility\x18\x01 \x01(\x0e\x32\x1e.FederatedQuery.Acl.Visibility\"@\n\nVisibility\x12\x1a\n\x16VISIBILITY_UNSPECIFIED\x10\x00\x12\x0b\n\x07PRIVATE\x10\x01\x12\t\n\x05SCOPE\x10\x02\"\x83\x03\n\x06Limits\x12!\n\x0fvcpu_rate_limit\x18\x01 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0f\x66low_rate_limit\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0fvcpu_time_limit\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0fmax_result_size\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0fmax_result_rows\x18\x05 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x1e\n\x0cmemory_limit\x18\x06 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12-\n\nresult_ttl\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x36\n\x11\x65xecution_timeout\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12\x38\n\x12\x65xecution_deadline\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x42\t\n\x07timeout\"\xef\x03\n\x14StreamingDisposition\x12(\n\x06oldest\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\'\n\x05\x66resh\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x42\n\tfrom_time\x18\x03 \x01(\x0b\x32-.FederatedQuery.StreamingDisposition.FromTimeH\x00\x12@\n\x08time_ago\x18\x04 \x01(\x0b\x32,.FederatedQuery.StreamingDisposition.TimeAgoH\x00\x12W\n\x14\x66rom_last_checkpoint\x18\x05 \x01(\x0b\x32\x37.FederatedQuery.StreamingDisposition.FromLastCheckpointH\x00\x1a\x39\n\x08\x46romTime\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x36\n\x07TimeAgo\x12+\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a#\n\x12\x46romLastCheckpoint\x12\r\n\x05\x66orce\x18\x01 \x01(\x08\x42\r\n\x0b\x64isposition\"\xe8\x05\n\x0cQueryContent\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.FederatedQuery.QueryContent.QueryType\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12 \n\x03\x61\x63l\x18\x03 \x01(\x0b\x32\x13.FederatedQuery.Acl\x12&\n\x06limits\x18\x04 \x01(\x0b\x32\x16.FederatedQuery.Limits\x12\x1a\n\x04text\x18\x05 \x01(\tB\x0c\xa2\xe6*\x08\n\x06\x08\x01\x10\x80\xa0\x06\x12\x11\n\tautomatic\x18\x06 \x01(\x08\x12\x1c\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x07\xa2\xe6*\x03\x18\x80P\x12\x64\n\x12\x65xecution_settings\x18\n \x03(\x0b\x32\x33.FederatedQuery.QueryContent.ExecutionSettingsEntryB\x13\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x03\x18\x80 \x12\x38\n\x06syntax\x18\x0b \x01(\x0e\x32(.FederatedQuery.QueryContent.QuerySyntax\x12N\n\nparameters\x18\x0c \x03(\x0b\x32,.FederatedQuery.QueryContent.ParametersEntryB\x0c\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\x1a\x38\n\x16\x45xecutionSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\"E\n\tQueryType\x12\x1a\n\x16QUERY_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tANALYTICS\x10\x01\x12\r\n\tSTREAMING\x10\x02\"?\n\x0bQuerySyntax\x12\x1c\n\x18QUERY_SYNTAX_UNSPECIFIED\x10\x00\x12\n\n\x06YQL_V1\x10\x01\x12\x06\n\x02PG\x10\x02\"\xe5\x01\n\nCommonMeta\x12\x17\n\x02id\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x1f\n\ncreated_by\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12 \n\x0bmodified_by\x18\x03 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bmodified_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x08revision\x18\x06 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\"\xbf\x06\n\tQueryMeta\x12*\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1a.FederatedQuery.CommonMeta\x12\x30\n\x0csubmitted_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x0c\x65xecute_mode\x18\x04 \x01(\x0e\x32\x1b.FederatedQuery.ExecuteMode\x12\x37\n\x06status\x18\x05 \x01(\x0e\x32\'.FederatedQuery.QueryMeta.ComputeStatus\x12\x1f\n\x17last_job_query_revision\x18\x06 \x01(\x03\x12\x13\n\x0blast_job_id\x18\x07 \x01(\t\x12-\n\texpire_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10result_expire_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nstarted_by\x18\n \x01(\t\x12\x14\n\naborted_by\x18\x0b \x01(\tH\x00\x12\x13\n\tpaused_by\x18\x0c \x01(\tH\x00\x12\x1d\n\x15has_saved_checkpoints\x18\r \x01(\x08\"\x83\x02\n\rComputeStatus\x12\x1e\n\x1a\x43OMPUTE_STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08STARTING\x10\x01\x12\x13\n\x0f\x41\x42ORTED_BY_USER\x10\x02\x12\x15\n\x11\x41\x42ORTED_BY_SYSTEM\x10\x03\x12\x14\n\x10\x41\x42ORTING_BY_USER\x10\x04\x12\x16\n\x12\x41\x42ORTING_BY_SYSTEM\x10\x05\x12\x0c\n\x08RESUMING\x10\x06\x12\x0b\n\x07RUNNING\x10\x07\x12\r\n\tCOMPLETED\x10\x08\x12\x0e\n\nCOMPLETING\x10\x0c\x12\n\n\x06\x46\x41ILED\x10\t\x12\x0b\n\x07\x46\x41ILING\x10\r\x12\n\n\x06PAUSED\x10\x0b\x12\x0b\n\x07PAUSING\x10\nB\x08\n\x06\x61\x63tion\"\xc9\x01\n\nBriefQuery\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.FederatedQuery.QueryContent.QueryType\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\'\n\x04meta\x18\x03 \x01(\x0b\x32\x19.FederatedQuery.QueryMeta\x12\x32\n\nvisibility\x18\x04 \x01(\x0e\x32\x1e.FederatedQuery.Acl.Visibility\x12\x11\n\tautomatic\x18\x05 \x01(\x08\"\x19\n\tQueryPlan\x12\x0c\n\x04json\x18\x01 \x01(\t\"\x18\n\x08QueryAst\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"]\n\rResultSetMeta\x12\x1b\n\x06\x63olumn\x18\x01 \x03(\x0b\x32\x0b.Ydb.Column\x12\x1c\n\nrows_count\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x11\n\ttruncated\x18\x03 \x01(\x08\"\x1c\n\rQueryTimeline\x12\x0b\n\x03svg\x18\x01 \x01(\t\"\xa7\x03\n\x05Query\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.FederatedQuery.QueryMeta\x12-\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x1c.FederatedQuery.QueryContent\x12\'\n\x04plan\x18\x03 \x01(\x0b\x32\x19.FederatedQuery.QueryPlan\x12&\n\x05issue\x18\x04 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x30\n\x0ftransient_issue\x18\x05 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x33\n\nstatistics\x18\x06 \x01(\x0b\x32\x1f.FederatedQuery.QueryStatistics\x12\x36\n\x0fresult_set_meta\x18\x07 \x03(\x0b\x32\x1d.FederatedQuery.ResultSetMeta\x12%\n\x03\x61st\x18\x08 \x01(\x0b\x32\x18.FederatedQuery.QueryAst\x12/\n\x08timeline\x18\t \x01(\x0b\x32\x1d.FederatedQuery.QueryTimeline\"\x1f\n\x0fQueryStatistics\x12\x0c\n\x04json\x18\x01 \x01(\t\"\x8e\x02\n\x12\x43reateQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12-\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x1c.FederatedQuery.QueryContent\x12\x31\n\x0c\x65xecute_mode\x18\x03 \x01(\x0e\x32\x1b.FederatedQuery.ExecuteMode\x12\x39\n\x0b\x64isposition\x18\x04 \x01(\x0b\x32$.FederatedQuery.StreamingDisposition\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"C\n\x13\x43reateQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\".\n\x11\x43reateQueryResult\x12\x19\n\x08query_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"\x93\x04\n\x12ListQueriesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12\x39\n\x06\x66ilter\x18\x04 \x01(\x0b\x32).FederatedQuery.ListQueriesRequest.Filter\x1a\xcc\x02\n\x06\x46ilter\x12:\n\nquery_type\x18\x01 \x01(\x0e\x32&.FederatedQuery.QueryContent.QueryType\x12?\n\x06status\x18\x02 \x03(\x0e\x32\'.FederatedQuery.QueryMeta.ComputeStatusB\x06\x9a\xe6*\x02\x18\x14\x12\x31\n\x04mode\x18\x03 \x03(\x0e\x32\x1b.FederatedQuery.ExecuteModeB\x06\x9a\xe6*\x02\x18\x14\x12\x15\n\x04name\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x05 \x01(\x08\x12\x32\n\nvisibility\x18\x06 \x01(\x0e\x32\x1e.FederatedQuery.Acl.Visibility\x12\x30\n\tautomatic\x18\x07 \x01(\x0e\x32\x1d.FederatedQuery.AutomaticType\"C\n\x13ListQueriesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"`\n\x11ListQueriesResult\x12)\n\x05query\x18\x01 \x03(\x0b\x32\x1a.FederatedQuery.BriefQuery\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"p\n\x14\x44\x65scribeQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"E\n\x15\x44\x65scribeQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\";\n\x13\x44\x65scribeQueryResult\x12$\n\x05query\x18\x01 \x01(\x0b\x32\x15.FederatedQuery.Query\"q\n\x15GetQueryStatusRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"F\n\x16GetQueryStatusResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"f\n\x14GetQueryStatusResult\x12\x37\n\x06status\x18\x01 \x01(\x0e\x32\'.FederatedQuery.QueryMeta.ComputeStatus\x12\x15\n\rmeta_revision\x18\x02 \x01(\x03\"\xb5\x01\n\x12\x44\x65leteQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12#\n\x11previous_revision\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"C\n\x13\x44\x65leteQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11\x44\x65leteQueryResult\"\x8a\x03\n\x12ModifyQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12-\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x1c.FederatedQuery.QueryContent\x12\x31\n\x0c\x65xecute_mode\x18\x04 \x01(\x0e\x32\x1b.FederatedQuery.ExecuteMode\x12\x39\n\x0b\x64isposition\x18\x05 \x01(\x0b\x32$.FederatedQuery.StreamingDisposition\x12\x36\n\x0fstate_load_mode\x18\x06 \x01(\x0e\x32\x1d.FederatedQuery.StateLoadMode\x12#\n\x11previous_revision\x18\x07 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x08 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"C\n\x13ModifyQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11ModifyQueryResult\"\xe3\x01\n\x13\x43ontrolQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12+\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x1b.FederatedQuery.QueryAction\x12#\n\x11previous_revision\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"D\n\x14\x43ontrolQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x14\n\x12\x43ontrolQueryResult\"\xed\x01\n\x08\x42riefJob\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.FederatedQuery.CommonMeta\x12-\n\nquery_meta\x18\x03 \x01(\x0b\x32\x19.FederatedQuery.QueryMeta\x12\x12\n\nquery_name\x18\t \x01(\t\x12\x32\n\nvisibility\x18\n \x01(\x0e\x32\x1e.FederatedQuery.Acl.Visibility\x12\x11\n\tautomatic\x18\x0b \x01(\x08\x12-\n\texpire_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x80\x05\n\x03Job\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.FederatedQuery.CommonMeta\x12\x0c\n\x04text\x18\x02 \x01(\t\x12-\n\nquery_meta\x18\x03 \x01(\x0b\x32\x19.FederatedQuery.QueryMeta\x12\'\n\x04plan\x18\x04 \x01(\x0b\x32\x19.FederatedQuery.QueryPlan\x12&\n\x05issue\x18\x05 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x33\n\nstatistics\x18\x06 \x01(\x0b\x32\x1f.FederatedQuery.QueryStatistics\x12\x36\n\x0fresult_set_meta\x18\x07 \x03(\x0b\x32\x1d.FederatedQuery.ResultSetMeta\x12%\n\x03\x61st\x18\x08 \x01(\x0b\x32\x18.FederatedQuery.QueryAst\x12\x12\n\nquery_name\x18\t \x01(\t\x12 \n\x03\x61\x63l\x18\n \x01(\x0b\x32\x13.FederatedQuery.Acl\x12\x11\n\tautomatic\x18\x0b \x01(\x08\x12-\n\texpire_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x06syntax\x18\r \x01(\x0e\x32(.FederatedQuery.QueryContent.QuerySyntax\x12\x37\n\nparameters\x18\x0e \x03(\x0b\x32#.FederatedQuery.Job.ParametersEntry\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\"\x8c\x02\n\x0fListJobsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12\x10\n\x08query_id\x18\x05 \x01(\t\x12\x36\n\x06\x66ilter\x18\x04 \x01(\x0b\x32&.FederatedQuery.ListJobsRequest.Filter\x1a:\n\x06\x46ilter\x12\x19\n\x08query_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x02 \x01(\x08\"@\n\x10ListJobsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"Y\n\x0eListJobsResult\x12%\n\x03job\x18\x01 \x03(\x0b\x32\x18.FederatedQuery.BriefJob\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"l\n\x12\x44\x65scribeJobRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\x06job_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"C\n\x13\x44\x65scribeJobResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"5\n\x11\x44\x65scribeJobResult\x12 \n\x03job\x18\x01 \x01(\x0b\x32\x13.FederatedQuery.Job\"\x15\n\x13\x43urrentIAMTokenAuth\"\n\n\x08NoneAuth\")\n\x12ServiceAccountAuth\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"\'\n\tTokenAuth\x12\x1a\n\x05token\x18\x01 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\"\xe6\x01\n\x07IamAuth\x12:\n\x0b\x63urrent_iam\x18\x01 \x01(\x0b\x32#.FederatedQuery.CurrentIAMTokenAuthH\x00\x12=\n\x0fservice_account\x18\x02 \x01(\x0b\x32\".FederatedQuery.ServiceAccountAuthH\x00\x12(\n\x04none\x18\x03 \x01(\x0b\x32\x18.FederatedQuery.NoneAuthH\x00\x12*\n\x05token\x18\x04 \x01(\x0b\x32\x19.FederatedQuery.TokenAuthH\x00\x42\n\n\x08identity\"\xb0\x01\n\x0b\x44\x61taStreams\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12%\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\x12\x19\n\x08\x65ndpoint\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x19\n\x08\x64\x61tabase\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x0e\n\x06secure\x18\x05 \x01(\x08\x12\x16\n\x0eshared_reading\x18\x06 \x01(\x08\"g\n\nMonitoring\x12\x18\n\x07project\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\xc8\x01\x12\x18\n\x07\x63luster\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\xc8\x01\x12%\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\"\x98\x01\n\x0bYdbDatabase\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12%\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\x12\x19\n\x08\x65ndpoint\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x19\n\x08\x64\x61tabase\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x0e\n\x06secure\x18\x05 \x01(\x08\"\xf8\x01\n\x11\x43lickHouseCluster\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1e\n\rdatabase_name\x18\x08 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1a\n\x05login\x18\x02 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\x1d\n\x08password\x18\x03 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12%\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\x12\x15\n\x04host\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1c\n\x04port\x18\x06 \x01(\x05\x42\x0e\xb2\xe6*\n[0; 65536]\x12\x0e\n\x06secure\x18\x07 \x01(\x08\"Y\n\x17ObjectStorageConnection\x12\x17\n\x06\x62ucket\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12%\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\"\x91\x02\n\x11PostgreSQLCluster\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1e\n\rdatabase_name\x18\x08 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1a\n\x05login\x18\x02 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\x1d\n\x08password\x18\x03 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\x17\n\x06schema\x18\t \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12%\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\x12\x15\n\x04host\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1c\n\x04port\x18\x06 \x01(\x05\x42\x0e\xb2\xe6*\n[0; 65536]\x12\x0e\n\x06secure\x18\x07 \x01(\x08\"\xcb\x01\n\x10GreenplumCluster\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1e\n\rdatabase_name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1a\n\x05login\x18\x03 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\x1d\n\x08password\x18\x04 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\x17\n\x06schema\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12%\n\x04\x61uth\x18\x06 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\"\xae\x01\n\x0cMySQLCluster\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1e\n\rdatabase_name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1a\n\x05login\x18\x03 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\x1d\n\x08password\x18\x04 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12%\n\x04\x61uth\x18\x05 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\"C\n\x07Logging\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12%\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\"\xa4\x01\n\x10IcebergWarehouse\x12\x31\n\x02s3\x18\x01 \x01(\x0b\x32#.FederatedQuery.IcebergWarehouse.S3H\x00\x1aR\n\x02S3\x12\x1c\n\x06\x62ucket\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08H\x00\x88\x01\x01\x12\x1a\n\x04path\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08H\x01\x88\x01\x01\x42\t\n\x07_bucketB\x07\n\x05_pathB\t\n\x07payload\"\xc0\x02\n\x0eIcebergCatalog\x12\x37\n\x06hadoop\x18\x01 \x01(\x0b\x32%.FederatedQuery.IcebergCatalog.HadoopH\x00\x12\x46\n\x0ehive_metastore\x18\x02 \x01(\x0b\x32,.FederatedQuery.IcebergCatalog.HiveMetastoreH\x00\x1a\x37\n\x06Hadoop\x12\x1f\n\tdirectory\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08H\x00\x88\x01\x01\x42\x0c\n\n_directory\x1ai\n\rHiveMetastore\x12\x19\n\x03uri\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08H\x00\x88\x01\x01\x12#\n\rdatabase_name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08H\x01\x88\x01\x01\x42\x06\n\x04_uriB\x10\n\x0e_database_nameB\t\n\x07payload\"\xa0\x01\n\x07Iceberg\x12/\n\x0ewarehouse_auth\x18\x02 \x01(\x0b\x32\x17.FederatedQuery.IamAuth\x12\x33\n\twarehouse\x18\x03 \x01(\x0b\x32 .FederatedQuery.IcebergWarehouse\x12/\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32\x1e.FederatedQuery.IcebergCatalog\"\xc0\x06\n\x11\x43onnectionSetting\x12\x33\n\x0cydb_database\x18\x01 \x01(\x0b\x32\x1b.FederatedQuery.YdbDatabaseH\x00\x12?\n\x12\x63lickhouse_cluster\x18\x02 \x01(\x0b\x32!.FederatedQuery.ClickHouseClusterH\x00\x12\x33\n\x0c\x64\x61ta_streams\x18\x03 \x01(\x0b\x32\x1b.FederatedQuery.DataStreamsH\x00\x12\x41\n\x0eobject_storage\x18\x04 \x01(\x0b\x32\'.FederatedQuery.ObjectStorageConnectionH\x00\x12\x30\n\nmonitoring\x18\x05 \x01(\x0b\x32\x1a.FederatedQuery.MonitoringH\x00\x12?\n\x12postgresql_cluster\x18\x06 \x01(\x0b\x32!.FederatedQuery.PostgreSQLClusterH\x00\x12=\n\x11greenplum_cluster\x18\x07 \x01(\x0b\x32 .FederatedQuery.GreenplumClusterH\x00\x12\x35\n\rmysql_cluster\x18\x08 \x01(\x0b\x32\x1c.FederatedQuery.MySQLClusterH\x00\x12*\n\x07logging\x18\t \x01(\x0b\x32\x17.FederatedQuery.LoggingH\x00\x12*\n\x07iceberg\x18\n \x01(\x0b\x32\x17.FederatedQuery.IcebergH\x00\"\xed\x01\n\x0e\x43onnectionType\x12\x1f\n\x1b\x43ONNECTION_TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cYDB_DATABASE\x10\x01\x12\x16\n\x12\x43LICKHOUSE_CLUSTER\x10\x02\x12\x10\n\x0c\x44\x41TA_STREAMS\x10\x03\x12\x12\n\x0eOBJECT_STORAGE\x10\x04\x12\x0e\n\nMONITORING\x10\x05\x12\x16\n\x12POSTGRESQL_CLUSTER\x10\x06\x12\x15\n\x11GREENPLUM_CLUSTER\x10\x07\x12\x11\n\rMYSQL_CLUSTER\x10\x08\x12\x0b\n\x07LOGGING\x10\t\x12\x0b\n\x07ICEBERG\x10\nB\x0c\n\nconnection\"\xa2\x01\n\x11\x43onnectionContent\x12\x19\n\x04name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x32\n\x07setting\x18\x02 \x01(\x0b\x32!.FederatedQuery.ConnectionSetting\x12 \n\x03\x61\x63l\x18\x03 \x01(\x0b\x32\x13.FederatedQuery.Acl\x12\x1c\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80P\"j\n\nConnection\x12\x32\n\x07\x63ontent\x18\x01 \x01(\x0b\x32!.FederatedQuery.ConnectionContent\x12(\n\x04meta\x18\x02 \x01(\x0b\x32\x1a.FederatedQuery.CommonMeta\"\xaa\x01\n\x17\x43reateConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x32\n\x07\x63ontent\x18\x02 \x01(\x0b\x32!.FederatedQuery.ConnectionContent\x12 \n\x0fidempotency_key\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"H\n\x18\x43reateConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"<\n\x16\x43reateConnectionResult\x12\"\n\rconnection_id\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"\x84\x03\n\x16ListConnectionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12=\n\x06\x66ilter\x18\x04 \x01(\x0b\x32-.FederatedQuery.ListConnectionsRequest.Filter\x1a\xb5\x01\n\x06\x46ilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x02 \x01(\x08\x12I\n\x0f\x63onnection_type\x18\x03 \x01(\x0e\x32\x30.FederatedQuery.ConnectionSetting.ConnectionType\x12\x32\n\nvisibility\x18\x04 \x01(\x0e\x32\x1e.FederatedQuery.Acl.Visibility\"G\n\x17ListConnectionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"i\n\x15ListConnectionsResult\x12.\n\nconnection\x18\x01 \x03(\x0b\x32\x1a.FederatedQuery.Connection\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"z\n\x19\x44\x65scribeConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"J\n\x1a\x44\x65scribeConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"J\n\x18\x44\x65scribeConnectionResult\x12.\n\nconnection\x18\x01 \x01(\x0b\x32\x1a.FederatedQuery.Connection\"\xf3\x01\n\x17ModifyConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x32\n\x07\x63ontent\x18\x03 \x01(\x0b\x32!.FederatedQuery.ConnectionContent\x12#\n\x11previous_revision\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"H\n\x18ModifyConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x18\n\x16ModifyConnectionResult\"\xbf\x01\n\x17\x44\x65leteConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12#\n\x11previous_revision\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"H\n\x18\x44\x65leteConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x18\n\x16\x44\x65leteConnectionResult\"\x86\x01\n\x15TestConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x32\n\x07setting\x18\x02 \x01(\x0b\x32!.FederatedQuery.ConnectionSetting\"F\n\x16TestConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x16\n\x14TestConnectionResult\"\xcc\x01\n\x14GetResultDataRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\"\n\x10result_set_index\x18\x03 \x01(\x05\x42\x08\xb2\xe6*\x04>= 0\x12\x18\n\x06offset\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x1c\n\x05limit\x18\x05 \x01(\x03\x42\r\xb2\xe6*\t[1; 1000]\"E\n\x15GetResultDataResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"9\n\x13GetResultDataResult\x12\"\n\nresult_set\x18\x01 \x01(\x0b\x32\x0e.Ydb.ResultSet\".\n\x06Schema\x12$\n\x06\x63olumn\x18\x01 \x03(\x0b\x32\x0b.Ydb.ColumnB\x07\x9a\xe6*\x03\x18\xe8\x07\"\xa2\x02\n\x12\x44\x61taStreamsBinding\x12 \n\x0bstream_name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x17\n\x06\x66ormat\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1c\n\x0b\x63ompression\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12&\n\x06schema\x18\x04 \x01(\x0b\x32\x16.FederatedQuery.Schema\x12U\n\x0e\x66ormat_setting\x18\x05 \x03(\x0b\x32\x35.FederatedQuery.DataStreamsBinding.FormatSettingEntryB\x06\x9a\xe6*\x02\x18\x64\x1a\x34\n\x12\x46ormatSettingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x04\n\x14ObjectStorageBinding\x12;\n\x06subset\x18\x01 \x03(\x0b\x32+.FederatedQuery.ObjectStorageBinding.Subset\x1a\xbc\x03\n\x06Subset\x12!\n\x0cpath_pattern\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x17\n\x06\x66ormat\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12^\n\x0e\x66ormat_setting\x18\x03 \x03(\x0b\x32>.FederatedQuery.ObjectStorageBinding.Subset.FormatSettingEntryB\x06\x9a\xe6*\x02\x18\x64\x12\x1c\n\x0b\x63ompression\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12&\n\x06schema\x18\x05 \x01(\x0b\x32\x16.FederatedQuery.Schema\x12O\n\nprojection\x18\x06 \x03(\x0b\x32;.FederatedQuery.ObjectStorageBinding.Subset.ProjectionEntry\x12\x16\n\x0epartitioned_by\x18\x07 \x03(\t\x1a\x34\n\x12\x46ormatSettingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fProjectionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xea\x01\n\x0e\x42indingSetting\x12:\n\x0c\x64\x61ta_streams\x18\x01 \x01(\x0b\x32\".FederatedQuery.DataStreamsBindingH\x00\x12>\n\x0eobject_storage\x18\x02 \x01(\x0b\x32$.FederatedQuery.ObjectStorageBindingH\x00\"Q\n\x0b\x42indingType\x12\x1c\n\x18\x42INDING_TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x44\x41TA_STREAMS\x10\x01\x12\x12\n\x0eOBJECT_STORAGE\x10\x02\x42\t\n\x07\x62inding\"\xe5\x01\n\x0c\x42riefBinding\x12\x19\n\x04name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12(\n\x04meta\x18\x03 \x01(\x0b\x32\x1a.FederatedQuery.CommonMeta\x12\x38\n\x04type\x18\x04 \x01(\x0e\x32*.FederatedQuery.BindingSetting.BindingType\x12\x32\n\nvisibility\x18\x05 \x01(\x0e\x32\x1e.FederatedQuery.Acl.Visibility\"\xc0\x01\n\x0e\x42indingContent\x12\x19\n\x04name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12/\n\x07setting\x18\x03 \x01(\x0b\x32\x1e.FederatedQuery.BindingSetting\x12 \n\x03\x61\x63l\x18\x04 \x01(\x0b\x32\x13.FederatedQuery.Acl\x12\x1c\n\x0b\x64\x65scription\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80P\"d\n\x07\x42inding\x12/\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x1e.FederatedQuery.BindingContent\x12(\n\x04meta\x18\x02 \x01(\x0b\x32\x1a.FederatedQuery.CommonMeta\"\xa4\x01\n\x14\x43reateBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12/\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x1e.FederatedQuery.BindingContent\x12 \n\x0fidempotency_key\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"E\n\x15\x43reateBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"6\n\x13\x43reateBindingResult\x12\x1f\n\nbinding_id\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"\xd3\x02\n\x13ListBindingsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12:\n\x06\x66ilter\x18\x04 \x01(\x0b\x32*.FederatedQuery.ListBindingsRequest.Filter\x1a\x8a\x01\n\x06\x46ilter\x12\x1e\n\rconnection_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x03 \x01(\x08\x12\x32\n\nvisibility\x18\x04 \x01(\x0e\x32\x1e.FederatedQuery.Acl.Visibility\"D\n\x14ListBindingsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"e\n\x12ListBindingsResult\x12-\n\x07\x62inding\x18\x01 \x03(\x0b\x32\x1c.FederatedQuery.BriefBinding\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"t\n\x16\x44\x65scribeBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1f\n\nbinding_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"G\n\x17\x44\x65scribeBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"A\n\x15\x44\x65scribeBindingResult\x12(\n\x07\x62inding\x18\x01 \x01(\x0b\x32\x17.FederatedQuery.Binding\"\xea\x01\n\x14ModifyBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1f\n\nbinding_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12/\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x1e.FederatedQuery.BindingContent\x12#\n\x11previous_revision\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"E\n\x15ModifyBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x15\n\x13ModifyBindingResult\"\xb9\x01\n\x14\x44\x65leteBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1f\n\nbinding_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12#\n\x11previous_revision\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"E\n\x15\x44\x65leteBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x15\n\x13\x44\x65leteBindingResult*q\n\x0b\x45xecuteMode\x12\x1c\n\x18\x45XECUTE_MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04SAVE\x10\x01\x12\t\n\x05PARSE\x10\x02\x12\x0b\n\x07\x43OMPILE\x10\x03\x12\x0c\n\x08VALIDATE\x10\x04\x12\x0b\n\x07\x45XPLAIN\x10\x05\x12\x07\n\x03RUN\x10\x06*y\n\x0bQueryAction\x12\x1c\n\x18QUERY_ACTION_UNSPECIFIED\x10\x00\x12\t\n\x05PAUSE\x10\x01\x12\x14\n\x10PAUSE_GRACEFULLY\x10\x02\x12\t\n\x05\x41\x42ORT\x10\x03\x12\x14\n\x10\x41\x42ORT_GRACEFULLY\x10\x04\x12\n\n\x06RESUME\x10\x05*U\n\rStateLoadMode\x12\x1f\n\x1bSTATE_LOAD_MODE_UNSPECIFIED\x10\x00\x12\t\n\x05\x45MPTY\x10\x01\x12\x18\n\x14\x46ROM_LAST_CHECKPOINT\x10\x02*Q\n\rAutomaticType\x12\x1e\n\x1a\x41UTOMATIC_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tAUTOMATIC\x10\x01\x12\x11\n\rNOT_AUTOMATIC\x10\x02\x42r\n$tech.ydb.proto.draft.federated.queryZGgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_FederatedQuery\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'draft.protos.ydb_federated_query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$tech.ydb.proto.draft.federated.queryZGgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_FederatedQuery\370\001\001'
  _LIMITS.fields_by_name['vcpu_rate_limit']._options = None
  _LIMITS.fields_by_name['vcpu_rate_limit']._serialized_options = b'\262\346*\004>= 0'
  _LIMITS.fields_by_name['flow_rate_limit']._options = None
  _LIMITS.fields_by_name['flow_rate_limit']._serialized_options = b'\262\346*\004>= 0'
  _LIMITS.fields_by_name['vcpu_time_limit']._options = None
  _LIMITS.fields_by_name['vcpu_time_limit']._serialized_options = b'\262\346*\004>= 0'
  _LIMITS.fields_by_name['max_result_size']._options = None
  _LIMITS.fields_by_name['max_result_size']._serialized_options = b'\262\346*\004>= 0'
  _LIMITS.fields_by_name['max_result_rows']._options = None
  _LIMITS.fields_by_name['max_result_rows']._serialized_options = b'\262\346*\004>= 0'
  _LIMITS.fields_by_name['memory_limit']._options = None
  _LIMITS.fields_by_name['memory_limit']._serialized_options = b'\262\346*\004>= 0'
  _QUERYCONTENT_EXECUTIONSETTINGSENTRY._options = None
  _QUERYCONTENT_EXECUTIONSETTINGSENTRY._serialized_options = b'8\001'
  _QUERYCONTENT_PARAMETERSENTRY._options = None
  _QUERYCONTENT_PARAMETERSENTRY._serialized_options = b'8\001'
  _QUERYCONTENT.fields_by_name['name']._options = None
  _QUERYCONTENT.fields_by_name['name']._serialized_options = b'\242\346*\003\030\200\010'
  _QUERYCONTENT.fields_by_name['text']._options = None
  _QUERYCONTENT.fields_by_name['text']._serialized_options = b'\242\346*\010\n\006\010\001\020\200\240\006'
  _QUERYCONTENT.fields_by_name['description']._options = None
  _QUERYCONTENT.fields_by_name['description']._serialized_options = b'\242\346*\003\030\200P'
  _QUERYCONTENT.fields_by_name['execution_settings']._options = None
  _QUERYCONTENT.fields_by_name['execution_settings']._serialized_options = b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\003\030\200 '
  _QUERYCONTENT.fields_by_name['parameters']._options = None
  _QUERYCONTENT.fields_by_name['parameters']._serialized_options = b'\252\346*\010\n\006\n\004\010\001\020d'
  _COMMONMETA.fields_by_name['id']._options = None
  _COMMONMETA.fields_by_name['id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _COMMONMETA.fields_by_name['created_by']._options = None
  _COMMONMETA.fields_by_name['created_by']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _COMMONMETA.fields_by_name['modified_by']._options = None
  _COMMONMETA.fields_by_name['modified_by']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _COMMONMETA.fields_by_name['revision']._options = None
  _COMMONMETA.fields_by_name['revision']._serialized_options = b'\262\346*\004>= 0'
  _BRIEFQUERY.fields_by_name['name']._options = None
  _BRIEFQUERY.fields_by_name['name']._serialized_options = b'\242\346*\003\030\200\010'
  _RESULTSETMETA.fields_by_name['rows_count']._options = None
  _RESULTSETMETA.fields_by_name['rows_count']._serialized_options = b'\262\346*\004>= 0'
  _CREATEQUERYREQUEST.fields_by_name['idempotency_key']._options = None
  _CREATEQUERYREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _CREATEQUERYRESULT.fields_by_name['query_id']._options = None
  _CREATEQUERYRESULT.fields_by_name['query_id']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTQUERIESREQUEST_FILTER.fields_by_name['status']._options = None
  _LISTQUERIESREQUEST_FILTER.fields_by_name['status']._serialized_options = b'\232\346*\002\030\024'
  _LISTQUERIESREQUEST_FILTER.fields_by_name['mode']._options = None
  _LISTQUERIESREQUEST_FILTER.fields_by_name['mode']._serialized_options = b'\232\346*\002\030\024'
  _LISTQUERIESREQUEST_FILTER.fields_by_name['name']._options = None
  _LISTQUERIESREQUEST_FILTER.fields_by_name['name']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTQUERIESREQUEST.fields_by_name['page_token']._options = None
  _LISTQUERIESREQUEST.fields_by_name['page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTQUERIESREQUEST.fields_by_name['limit']._options = None
  _LISTQUERIESREQUEST.fields_by_name['limit']._serialized_options = b'\262\346*\010[1; 100]'
  _LISTQUERIESRESULT.fields_by_name['next_page_token']._options = None
  _LISTQUERIESRESULT.fields_by_name['next_page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _DESCRIBEQUERYREQUEST.fields_by_name['query_id']._options = None
  _DESCRIBEQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _GETQUERYSTATUSREQUEST.fields_by_name['query_id']._options = None
  _GETQUERYSTATUSREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _DELETEQUERYREQUEST.fields_by_name['query_id']._options = None
  _DELETEQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _DELETEQUERYREQUEST.fields_by_name['previous_revision']._options = None
  _DELETEQUERYREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _DELETEQUERYREQUEST.fields_by_name['idempotency_key']._options = None
  _DELETEQUERYREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _MODIFYQUERYREQUEST.fields_by_name['query_id']._options = None
  _MODIFYQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _MODIFYQUERYREQUEST.fields_by_name['previous_revision']._options = None
  _MODIFYQUERYREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _MODIFYQUERYREQUEST.fields_by_name['idempotency_key']._options = None
  _MODIFYQUERYREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _CONTROLQUERYREQUEST.fields_by_name['query_id']._options = None
  _CONTROLQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _CONTROLQUERYREQUEST.fields_by_name['previous_revision']._options = None
  _CONTROLQUERYREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _CONTROLQUERYREQUEST.fields_by_name['idempotency_key']._options = None
  _CONTROLQUERYREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _JOB_PARAMETERSENTRY._options = None
  _JOB_PARAMETERSENTRY._serialized_options = b'8\001'
  _LISTJOBSREQUEST_FILTER.fields_by_name['query_id']._options = None
  _LISTJOBSREQUEST_FILTER.fields_by_name['query_id']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTJOBSREQUEST.fields_by_name['page_token']._options = None
  _LISTJOBSREQUEST.fields_by_name['page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTJOBSREQUEST.fields_by_name['limit']._options = None
  _LISTJOBSREQUEST.fields_by_name['limit']._serialized_options = b'\262\346*\010[1; 100]'
  _LISTJOBSRESULT.fields_by_name['next_page_token']._options = None
  _LISTJOBSRESULT.fields_by_name['next_page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _DESCRIBEJOBREQUEST.fields_by_name['job_id']._options = None
  _DESCRIBEJOBREQUEST.fields_by_name['job_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _SERVICEACCOUNTAUTH.fields_by_name['id']._options = None
  _SERVICEACCOUNTAUTH.fields_by_name['id']._serialized_options = b'\242\346*\003\030\200\010'
  _TOKENAUTH.fields_by_name['token']._options = None
  _TOKENAUTH.fields_by_name['token']._serialized_options = b'\242\346*\003\030\200\010\270\346*\001'
  _DATASTREAMS.fields_by_name['database_id']._options = None
  _DATASTREAMS.fields_by_name['database_id']._serialized_options = b'\242\346*\003\030\200\010'
  _DATASTREAMS.fields_by_name['endpoint']._options = None
  _DATASTREAMS.fields_by_name['endpoint']._serialized_options = b'\242\346*\003\030\200\010'
  _DATASTREAMS.fields_by_name['database']._options = None
  _DATASTREAMS.fields_by_name['database']._serialized_options = b'\242\346*\003\030\200\010'
  _MONITORING.fields_by_name['project']._options = None
  _MONITORING.fields_by_name['project']._serialized_options = b'\242\346*\003\030\310\001'
  _MONITORING.fields_by_name['cluster']._options = None
  _MONITORING.fields_by_name['cluster']._serialized_options = b'\242\346*\003\030\310\001'
  _YDBDATABASE.fields_by_name['database_id']._options = None
  _YDBDATABASE.fields_by_name['database_id']._serialized_options = b'\242\346*\003\030\200\010'
  _YDBDATABASE.fields_by_name['endpoint']._options = None
  _YDBDATABASE.fields_by_name['endpoint']._serialized_options = b'\242\346*\003\030\200\010'
  _YDBDATABASE.fields_by_name['database']._options = None
  _YDBDATABASE.fields_by_name['database']._serialized_options = b'\242\346*\003\030\200\010'
  _CLICKHOUSECLUSTER.fields_by_name['database_id']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['database_id']._serialized_options = b'\242\346*\003\030\200\010'
  _CLICKHOUSECLUSTER.fields_by_name['database_name']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['database_name']._serialized_options = b'\242\346*\003\030\200\010'
  _CLICKHOUSECLUSTER.fields_by_name['login']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['login']._serialized_options = b'\242\346*\003\030\200\010\270\346*\001'
  _CLICKHOUSECLUSTER.fields_by_name['password']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['password']._serialized_options = b'\242\346*\003\030\200\010\270\346*\001'
  _CLICKHOUSECLUSTER.fields_by_name['host']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['host']._serialized_options = b'\242\346*\003\030\200\010'
  _CLICKHOUSECLUSTER.fields_by_name['port']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['port']._serialized_options = b'\262\346*\n[0; 65536]'
  _OBJECTSTORAGECONNECTION.fields_by_name['bucket']._options = None
  _OBJECTSTORAGECONNECTION.fields_by_name['bucket']._serialized_options = b'\242\346*\003\030\200\010'
  _POSTGRESQLCLUSTER.fields_by_name['database_id']._options = None
  _POSTGRESQLCLUSTER.fields_by_name['database_id']._serialized_options = b'\242\346*\003\030\200\010'
  _POSTGRESQLCLUSTER.fields_by_name['database_name']._options = None
  _POSTGRESQLCLUSTER.fields_by_name['database_name']._serialized_options = b'\242\346*\003\030\200\010'
  _POSTGRESQLCLUSTER.fields_by_name['login']._options = None
  _POSTGRESQLCLUSTER.fields_by_name['login']._serialized_options = b'\242\346*\003\030\200\010\270\346*\001'
  _POSTGRESQLCLUSTER.fields_by_name['password']._options = None
  _POSTGRESQLCLUSTER.fields_by_name['password']._serialized_options = b'\242\346*\003\030\200\010\270\346*\001'
  _POSTGRESQLCLUSTER.fields_by_name['schema']._options = None
  _POSTGRESQLCLUSTER.fields_by_name['schema']._serialized_options = b'\242\346*\003\030\200\010'
  _POSTGRESQLCLUSTER.fields_by_name['host']._options = None
  _POSTGRESQLCLUSTER.fields_by_name['host']._serialized_options = b'\242\346*\003\030\200\010'
  _POSTGRESQLCLUSTER.fields_by_name['port']._options = None
  _POSTGRESQLCLUSTER.fields_by_name['port']._serialized_options = b'\262\346*\n[0; 65536]'
  _GREENPLUMCLUSTER.fields_by_name['database_id']._options = None
  _GREENPLUMCLUSTER.fields_by_name['database_id']._serialized_options = b'\242\346*\003\030\200\010'
  _GREENPLUMCLUSTER.fields_by_name['database_name']._options = None
  _GREENPLUMCLUSTER.fields_by_name['database_name']._serialized_options = b'\242\346*\003\030\200\010'
  _GREENPLUMCLUSTER.fields_by_name['login']._options = None
  _GREENPLUMCLUSTER.fields_by_name['login']._serialized_options = b'\242\346*\003\030\200\010\270\346*\001'
  _GREENPLUMCLUSTER.fields_by_name['password']._options = None
  _GREENPLUMCLUSTER.fields_by_name['password']._serialized_options = b'\242\346*\003\030\200\010\270\346*\001'
  _GREENPLUMCLUSTER.fields_by_name['schema']._options = None
  _GREENPLUMCLUSTER.fields_by_name['schema']._serialized_options = b'\242\346*\003\030\200\010'
  _MYSQLCLUSTER.fields_by_name['database_id']._options = None
  _MYSQLCLUSTER.fields_by_name['database_id']._serialized_options = b'\242\346*\003\030\200\010'
  _MYSQLCLUSTER.fields_by_name['database_name']._options = None
  _MYSQLCLUSTER.fields_by_name['database_name']._serialized_options = b'\242\346*\003\030\200\010'
  _MYSQLCLUSTER.fields_by_name['login']._options = None
  _MYSQLCLUSTER.fields_by_name['login']._serialized_options = b'\242\346*\003\030\200\010\270\346*\001'
  _MYSQLCLUSTER.fields_by_name['password']._options = None
  _MYSQLCLUSTER.fields_by_name['password']._serialized_options = b'\242\346*\003\030\200\010\270\346*\001'
  _ICEBERGWAREHOUSE_S3.fields_by_name['bucket']._options = None
  _ICEBERGWAREHOUSE_S3.fields_by_name['bucket']._serialized_options = b'\242\346*\003\030\200\010'
  _ICEBERGWAREHOUSE_S3.fields_by_name['path']._options = None
  _ICEBERGWAREHOUSE_S3.fields_by_name['path']._serialized_options = b'\242\346*\003\030\200\010'
  _ICEBERGCATALOG_HADOOP.fields_by_name['directory']._options = None
  _ICEBERGCATALOG_HADOOP.fields_by_name['directory']._serialized_options = b'\242\346*\003\030\200\010'
  _ICEBERGCATALOG_HIVEMETASTORE.fields_by_name['uri']._options = None
  _ICEBERGCATALOG_HIVEMETASTORE.fields_by_name['uri']._serialized_options = b'\242\346*\003\030\200\010'
  _ICEBERGCATALOG_HIVEMETASTORE.fields_by_name['database_name']._options = None
  _ICEBERGCATALOG_HIVEMETASTORE.fields_by_name['database_name']._serialized_options = b'\242\346*\003\030\200\010'
  _CONNECTIONCONTENT.fields_by_name['name']._options = None
  _CONNECTIONCONTENT.fields_by_name['name']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _CONNECTIONCONTENT.fields_by_name['description']._options = None
  _CONNECTIONCONTENT.fields_by_name['description']._serialized_options = b'\242\346*\003\030\200P'
  _CREATECONNECTIONREQUEST.fields_by_name['idempotency_key']._options = None
  _CREATECONNECTIONREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _CREATECONNECTIONRESULT.fields_by_name['connection_id']._options = None
  _CREATECONNECTIONRESULT.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _LISTCONNECTIONSREQUEST_FILTER.fields_by_name['name']._options = None
  _LISTCONNECTIONSREQUEST_FILTER.fields_by_name['name']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTCONNECTIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCONNECTIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTCONNECTIONSREQUEST.fields_by_name['limit']._options = None
  _LISTCONNECTIONSREQUEST.fields_by_name['limit']._serialized_options = b'\262\346*\010[1; 100]'
  _LISTCONNECTIONSRESULT.fields_by_name['next_page_token']._options = None
  _LISTCONNECTIONSRESULT.fields_by_name['next_page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _DESCRIBECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _DESCRIBECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _MODIFYCONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _MODIFYCONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _MODIFYCONNECTIONREQUEST.fields_by_name['previous_revision']._options = None
  _MODIFYCONNECTIONREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _MODIFYCONNECTIONREQUEST.fields_by_name['idempotency_key']._options = None
  _MODIFYCONNECTIONREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _DELETECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _DELETECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _DELETECONNECTIONREQUEST.fields_by_name['previous_revision']._options = None
  _DELETECONNECTIONREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _DELETECONNECTIONREQUEST.fields_by_name['idempotency_key']._options = None
  _DELETECONNECTIONREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _GETRESULTDATAREQUEST.fields_by_name['query_id']._options = None
  _GETRESULTDATAREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _GETRESULTDATAREQUEST.fields_by_name['result_set_index']._options = None
  _GETRESULTDATAREQUEST.fields_by_name['result_set_index']._serialized_options = b'\262\346*\004>= 0'
  _GETRESULTDATAREQUEST.fields_by_name['offset']._options = None
  _GETRESULTDATAREQUEST.fields_by_name['offset']._serialized_options = b'\262\346*\004>= 0'
  _GETRESULTDATAREQUEST.fields_by_name['limit']._options = None
  _GETRESULTDATAREQUEST.fields_by_name['limit']._serialized_options = b'\262\346*\t[1; 1000]'
  _SCHEMA.fields_by_name['column']._options = None
  _SCHEMA.fields_by_name['column']._serialized_options = b'\232\346*\003\030\350\007'
  _DATASTREAMSBINDING_FORMATSETTINGENTRY._options = None
  _DATASTREAMSBINDING_FORMATSETTINGENTRY._serialized_options = b'8\001'
  _DATASTREAMSBINDING.fields_by_name['stream_name']._options = None
  _DATASTREAMSBINDING.fields_by_name['stream_name']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _DATASTREAMSBINDING.fields_by_name['format']._options = None
  _DATASTREAMSBINDING.fields_by_name['format']._serialized_options = b'\242\346*\003\030\200\010'
  _DATASTREAMSBINDING.fields_by_name['compression']._options = None
  _DATASTREAMSBINDING.fields_by_name['compression']._serialized_options = b'\242\346*\003\030\200\010'
  _DATASTREAMSBINDING.fields_by_name['format_setting']._options = None
  _DATASTREAMSBINDING.fields_by_name['format_setting']._serialized_options = b'\232\346*\002\030d'
  _OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY._options = None
  _OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY._serialized_options = b'8\001'
  _OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY._options = None
  _OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY._serialized_options = b'8\001'
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['path_pattern']._options = None
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['path_pattern']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['format']._options = None
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['format']._serialized_options = b'\242\346*\003\030\200\010'
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['format_setting']._options = None
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['format_setting']._serialized_options = b'\232\346*\002\030d'
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['compression']._options = None
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['compression']._serialized_options = b'\242\346*\003\030\200\010'
  _BRIEFBINDING.fields_by_name['name']._options = None
  _BRIEFBINDING.fields_by_name['name']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _BRIEFBINDING.fields_by_name['connection_id']._options = None
  _BRIEFBINDING.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _BINDINGCONTENT.fields_by_name['name']._options = None
  _BINDINGCONTENT.fields_by_name['name']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _BINDINGCONTENT.fields_by_name['connection_id']._options = None
  _BINDINGCONTENT.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _BINDINGCONTENT.fields_by_name['description']._options = None
  _BINDINGCONTENT.fields_by_name['description']._serialized_options = b'\242\346*\003\030\200P'
  _CREATEBINDINGREQUEST.fields_by_name['idempotency_key']._options = None
  _CREATEBINDINGREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _CREATEBINDINGRESULT.fields_by_name['binding_id']._options = None
  _CREATEBINDINGRESULT.fields_by_name['binding_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _LISTBINDINGSREQUEST_FILTER.fields_by_name['connection_id']._options = None
  _LISTBINDINGSREQUEST_FILTER.fields_by_name['connection_id']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTBINDINGSREQUEST_FILTER.fields_by_name['name']._options = None
  _LISTBINDINGSREQUEST_FILTER.fields_by_name['name']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTBINDINGSREQUEST.fields_by_name['page_token']._options = None
  _LISTBINDINGSREQUEST.fields_by_name['page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTBINDINGSREQUEST.fields_by_name['limit']._options = None
  _LISTBINDINGSREQUEST.fields_by_name['limit']._serialized_options = b'\262\346*\010[1; 100]'
  _LISTBINDINGSRESULT.fields_by_name['next_page_token']._options = None
  _LISTBINDINGSRESULT.fields_by_name['next_page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _DESCRIBEBINDINGREQUEST.fields_by_name['binding_id']._options = None
  _DESCRIBEBINDINGREQUEST.fields_by_name['binding_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _MODIFYBINDINGREQUEST.fields_by_name['binding_id']._options = None
  _MODIFYBINDINGREQUEST.fields_by_name['binding_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _MODIFYBINDINGREQUEST.fields_by_name['previous_revision']._options = None
  _MODIFYBINDINGREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _MODIFYBINDINGREQUEST.fields_by_name['idempotency_key']._options = None
  _MODIFYBINDINGREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _DELETEBINDINGREQUEST.fields_by_name['binding_id']._options = None
  _DELETEBINDINGREQUEST.fields_by_name['binding_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _DELETEBINDINGREQUEST.fields_by_name['previous_revision']._options = None
  _DELETEBINDINGREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _DELETEBINDINGREQUEST.fields_by_name['idempotency_key']._options = None
  _DELETEBINDINGREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _EXECUTEMODE._serialized_start=17540
  _EXECUTEMODE._serialized_end=17653
  _QUERYACTION._serialized_start=17655
  _QUERYACTION._serialized_end=17776
  _STATELOADMODE._serialized_start=17778
  _STATELOADMODE._serialized_end=17863
  _AUTOMATICTYPE._serialized_start=17865
  _AUTOMATICTYPE._serialized_end=17946
  _ACL._serialized_start=309
  _ACL._serialized_end=432
  _ACL_VISIBILITY._serialized_start=368
  _ACL_VISIBILITY._serialized_end=432
  _LIMITS._serialized_start=435
  _LIMITS._serialized_end=822
  _STREAMINGDISPOSITION._serialized_start=825
  _STREAMINGDISPOSITION._serialized_end=1320
  _STREAMINGDISPOSITION_FROMTIME._serialized_start=1155
  _STREAMINGDISPOSITION_FROMTIME._serialized_end=1212
  _STREAMINGDISPOSITION_TIMEAGO._serialized_start=1214
  _STREAMINGDISPOSITION_TIMEAGO._serialized_end=1268
  _STREAMINGDISPOSITION_FROMLASTCHECKPOINT._serialized_start=1270
  _STREAMINGDISPOSITION_FROMLASTCHECKPOINT._serialized_end=1305
  _QUERYCONTENT._serialized_start=1323
  _QUERYCONTENT._serialized_end=2067
  _QUERYCONTENT_EXECUTIONSETTINGSENTRY._serialized_start=1807
  _QUERYCONTENT_EXECUTIONSETTINGSENTRY._serialized_end=1863
  _QUERYCONTENT_PARAMETERSENTRY._serialized_start=1865
  _QUERYCONTENT_PARAMETERSENTRY._serialized_end=1931
  _QUERYCONTENT_QUERYTYPE._serialized_start=1933
  _QUERYCONTENT_QUERYTYPE._serialized_end=2002
  _QUERYCONTENT_QUERYSYNTAX._serialized_start=2004
  _QUERYCONTENT_QUERYSYNTAX._serialized_end=2067
  _COMMONMETA._serialized_start=2070
  _COMMONMETA._serialized_end=2299
  _QUERYMETA._serialized_start=2302
  _QUERYMETA._serialized_end=3133
  _QUERYMETA_COMPUTESTATUS._serialized_start=2864
  _QUERYMETA_COMPUTESTATUS._serialized_end=3123
  _BRIEFQUERY._serialized_start=3136
  _BRIEFQUERY._serialized_end=3337
  _QUERYPLAN._serialized_start=3339
  _QUERYPLAN._serialized_end=3364
  _QUERYAST._serialized_start=3366
  _QUERYAST._serialized_end=3390
  _RESULTSETMETA._serialized_start=3392
  _RESULTSETMETA._serialized_end=3485
  _QUERYTIMELINE._serialized_start=3487
  _QUERYTIMELINE._serialized_end=3515
  _QUERY._serialized_start=3518
  _QUERY._serialized_end=3941
  _QUERYSTATISTICS._serialized_start=3943
  _QUERYSTATISTICS._serialized_end=3974
  _CREATEQUERYREQUEST._serialized_start=3977
  _CREATEQUERYREQUEST._serialized_end=4247
  _CREATEQUERYRESPONSE._serialized_start=4249
  _CREATEQUERYRESPONSE._serialized_end=4316
  _CREATEQUERYRESULT._serialized_start=4318
  _CREATEQUERYRESULT._serialized_end=4364
  _LISTQUERIESREQUEST._serialized_start=4367
  _LISTQUERIESREQUEST._serialized_end=4898
  _LISTQUERIESREQUEST_FILTER._serialized_start=4566
  _LISTQUERIESREQUEST_FILTER._serialized_end=4898
  _LISTQUERIESRESPONSE._serialized_start=4900
  _LISTQUERIESRESPONSE._serialized_end=4967
  _LISTQUERIESRESULT._serialized_start=4969
  _LISTQUERIESRESULT._serialized_end=5065
  _DESCRIBEQUERYREQUEST._serialized_start=5067
  _DESCRIBEQUERYREQUEST._serialized_end=5179
  _DESCRIBEQUERYRESPONSE._serialized_start=5181
  _DESCRIBEQUERYRESPONSE._serialized_end=5250
  _DESCRIBEQUERYRESULT._serialized_start=5252
  _DESCRIBEQUERYRESULT._serialized_end=5311
  _GETQUERYSTATUSREQUEST._serialized_start=5313
  _GETQUERYSTATUSREQUEST._serialized_end=5426
  _GETQUERYSTATUSRESPONSE._serialized_start=5428
  _GETQUERYSTATUSRESPONSE._serialized_end=5498
  _GETQUERYSTATUSRESULT._serialized_start=5500
  _GETQUERYSTATUSRESULT._serialized_end=5602
  _DELETEQUERYREQUEST._serialized_start=5605
  _DELETEQUERYREQUEST._serialized_end=5786
  _DELETEQUERYRESPONSE._serialized_start=5788
  _DELETEQUERYRESPONSE._serialized_end=5855
  _DELETEQUERYRESULT._serialized_start=5857
  _DELETEQUERYRESULT._serialized_end=5876
  _MODIFYQUERYREQUEST._serialized_start=5879
  _MODIFYQUERYREQUEST._serialized_end=6273
  _MODIFYQUERYRESPONSE._serialized_start=6275
  _MODIFYQUERYRESPONSE._serialized_end=6342
  _MODIFYQUERYRESULT._serialized_start=6344
  _MODIFYQUERYRESULT._serialized_end=6363
  _CONTROLQUERYREQUEST._serialized_start=6366
  _CONTROLQUERYREQUEST._serialized_end=6593
  _CONTROLQUERYRESPONSE._serialized_start=6595
  _CONTROLQUERYRESPONSE._serialized_end=6663
  _CONTROLQUERYRESULT._serialized_start=6665
  _CONTROLQUERYRESULT._serialized_end=6685
  _BRIEFJOB._serialized_start=6688
  _BRIEFJOB._serialized_end=6925
  _JOB._serialized_start=6928
  _JOB._serialized_end=7568
  _JOB_PARAMETERSENTRY._serialized_start=1865
  _JOB_PARAMETERSENTRY._serialized_end=1931
  _LISTJOBSREQUEST._serialized_start=7571
  _LISTJOBSREQUEST._serialized_end=7839
  _LISTJOBSREQUEST_FILTER._serialized_start=7781
  _LISTJOBSREQUEST_FILTER._serialized_end=7839
  _LISTJOBSRESPONSE._serialized_start=7841
  _LISTJOBSRESPONSE._serialized_end=7905
  _LISTJOBSRESULT._serialized_start=7907
  _LISTJOBSRESULT._serialized_end=7996
  _DESCRIBEJOBREQUEST._serialized_start=7998
  _DESCRIBEJOBREQUEST._serialized_end=8106
  _DESCRIBEJOBRESPONSE._serialized_start=8108
  _DESCRIBEJOBRESPONSE._serialized_end=8175
  _DESCRIBEJOBRESULT._serialized_start=8177
  _DESCRIBEJOBRESULT._serialized_end=8230
  _CURRENTIAMTOKENAUTH._serialized_start=8232
  _CURRENTIAMTOKENAUTH._serialized_end=8253
  _NONEAUTH._serialized_start=8255
  _NONEAUTH._serialized_end=8265
  _SERVICEACCOUNTAUTH._serialized_start=8267
  _SERVICEACCOUNTAUTH._serialized_end=8308
  _TOKENAUTH._serialized_start=8310
  _TOKENAUTH._serialized_end=8349
  _IAMAUTH._serialized_start=8352
  _IAMAUTH._serialized_end=8582
  _DATASTREAMS._serialized_start=8585
  _DATASTREAMS._serialized_end=8761
  _MONITORING._serialized_start=8763
  _MONITORING._serialized_end=8866
  _YDBDATABASE._serialized_start=8869
  _YDBDATABASE._serialized_end=9021
  _CLICKHOUSECLUSTER._serialized_start=9024
  _CLICKHOUSECLUSTER._serialized_end=9272
  _OBJECTSTORAGECONNECTION._serialized_start=9274
  _OBJECTSTORAGECONNECTION._serialized_end=9363
  _POSTGRESQLCLUSTER._serialized_start=9366
  _POSTGRESQLCLUSTER._serialized_end=9639
  _GREENPLUMCLUSTER._serialized_start=9642
  _GREENPLUMCLUSTER._serialized_end=9845
  _MYSQLCLUSTER._serialized_start=9848
  _MYSQLCLUSTER._serialized_end=10022
  _LOGGING._serialized_start=10024
  _LOGGING._serialized_end=10091
  _ICEBERGWAREHOUSE._serialized_start=10094
  _ICEBERGWAREHOUSE._serialized_end=10258
  _ICEBERGWAREHOUSE_S3._serialized_start=10165
  _ICEBERGWAREHOUSE_S3._serialized_end=10247
  _ICEBERGCATALOG._serialized_start=10261
  _ICEBERGCATALOG._serialized_end=10581
  _ICEBERGCATALOG_HADOOP._serialized_start=10408
  _ICEBERGCATALOG_HADOOP._serialized_end=10463
  _ICEBERGCATALOG_HIVEMETASTORE._serialized_start=10465
  _ICEBERGCATALOG_HIVEMETASTORE._serialized_end=10570
  _ICEBERG._serialized_start=10584
  _ICEBERG._serialized_end=10744
  _CONNECTIONSETTING._serialized_start=10747
  _CONNECTIONSETTING._serialized_end=11579
  _CONNECTIONSETTING_CONNECTIONTYPE._serialized_start=11328
  _CONNECTIONSETTING_CONNECTIONTYPE._serialized_end=11565
  _CONNECTIONCONTENT._serialized_start=11582
  _CONNECTIONCONTENT._serialized_end=11744
  _CONNECTION._serialized_start=11746
  _CONNECTION._serialized_end=11852
  _CREATECONNECTIONREQUEST._serialized_start=11855
  _CREATECONNECTIONREQUEST._serialized_end=12025
  _CREATECONNECTIONRESPONSE._serialized_start=12027
  _CREATECONNECTIONRESPONSE._serialized_end=12099
  _CREATECONNECTIONRESULT._serialized_start=12101
  _CREATECONNECTIONRESULT._serialized_end=12161
  _LISTCONNECTIONSREQUEST._serialized_start=12164
  _LISTCONNECTIONSREQUEST._serialized_end=12552
  _LISTCONNECTIONSREQUEST_FILTER._serialized_start=12371
  _LISTCONNECTIONSREQUEST_FILTER._serialized_end=12552
  _LISTCONNECTIONSRESPONSE._serialized_start=12554
  _LISTCONNECTIONSRESPONSE._serialized_end=12625
  _LISTCONNECTIONSRESULT._serialized_start=12627
  _LISTCONNECTIONSRESULT._serialized_end=12732
  _DESCRIBECONNECTIONREQUEST._serialized_start=12734
  _DESCRIBECONNECTIONREQUEST._serialized_end=12856
  _DESCRIBECONNECTIONRESPONSE._serialized_start=12858
  _DESCRIBECONNECTIONRESPONSE._serialized_end=12932
  _DESCRIBECONNECTIONRESULT._serialized_start=12934
  _DESCRIBECONNECTIONRESULT._serialized_end=13008
  _MODIFYCONNECTIONREQUEST._serialized_start=13011
  _MODIFYCONNECTIONREQUEST._serialized_end=13254
  _MODIFYCONNECTIONRESPONSE._serialized_start=13256
  _MODIFYCONNECTIONRESPONSE._serialized_end=13328
  _MODIFYCONNECTIONRESULT._serialized_start=13330
  _MODIFYCONNECTIONRESULT._serialized_end=13354
  _DELETECONNECTIONREQUEST._serialized_start=13357
  _DELETECONNECTIONREQUEST._serialized_end=13548
  _DELETECONNECTIONRESPONSE._serialized_start=13550
  _DELETECONNECTIONRESPONSE._serialized_end=13622
  _DELETECONNECTIONRESULT._serialized_start=13624
  _DELETECONNECTIONRESULT._serialized_end=13648
  _TESTCONNECTIONREQUEST._serialized_start=13651
  _TESTCONNECTIONREQUEST._serialized_end=13785
  _TESTCONNECTIONRESPONSE._serialized_start=13787
  _TESTCONNECTIONRESPONSE._serialized_end=13857
  _TESTCONNECTIONRESULT._serialized_start=13859
  _TESTCONNECTIONRESULT._serialized_end=13881
  _GETRESULTDATAREQUEST._serialized_start=13884
  _GETRESULTDATAREQUEST._serialized_end=14088
  _GETRESULTDATARESPONSE._serialized_start=14090
  _GETRESULTDATARESPONSE._serialized_end=14159
  _GETRESULTDATARESULT._serialized_start=14161
  _GETRESULTDATARESULT._serialized_end=14218
  _SCHEMA._serialized_start=14220
  _SCHEMA._serialized_end=14266
  _DATASTREAMSBINDING._serialized_start=14269
  _DATASTREAMSBINDING._serialized_end=14559
  _DATASTREAMSBINDING_FORMATSETTINGENTRY._serialized_start=14507
  _DATASTREAMSBINDING_FORMATSETTINGENTRY._serialized_end=14559
  _OBJECTSTORAGEBINDING._serialized_start=14562
  _OBJECTSTORAGEBINDING._serialized_end=15092
  _OBJECTSTORAGEBINDING_SUBSET._serialized_start=14648
  _OBJECTSTORAGEBINDING_SUBSET._serialized_end=15092
  _OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY._serialized_start=14507
  _OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY._serialized_end=14559
  _OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY._serialized_start=15043
  _OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY._serialized_end=15092
  _BINDINGSETTING._serialized_start=15095
  _BINDINGSETTING._serialized_end=15329
  _BINDINGSETTING_BINDINGTYPE._serialized_start=15237
  _BINDINGSETTING_BINDINGTYPE._serialized_end=15318
  _BRIEFBINDING._serialized_start=15332
  _BRIEFBINDING._serialized_end=15561
  _BINDINGCONTENT._serialized_start=15564
  _BINDINGCONTENT._serialized_end=15756
  _BINDING._serialized_start=15758
  _BINDING._serialized_end=15858
  _CREATEBINDINGREQUEST._serialized_start=15861
  _CREATEBINDINGREQUEST._serialized_end=16025
  _CREATEBINDINGRESPONSE._serialized_start=16027
  _CREATEBINDINGRESPONSE._serialized_end=16096
  _CREATEBINDINGRESULT._serialized_start=16098
  _CREATEBINDINGRESULT._serialized_end=16152
  _LISTBINDINGSREQUEST._serialized_start=16155
  _LISTBINDINGSREQUEST._serialized_end=16494
  _LISTBINDINGSREQUEST_FILTER._serialized_start=16356
  _LISTBINDINGSREQUEST_FILTER._serialized_end=16494
  _LISTBINDINGSRESPONSE._serialized_start=16496
  _LISTBINDINGSRESPONSE._serialized_end=16564
  _LISTBINDINGSRESULT._serialized_start=16566
  _LISTBINDINGSRESULT._serialized_end=16667
  _DESCRIBEBINDINGREQUEST._serialized_start=16669
  _DESCRIBEBINDINGREQUEST._serialized_end=16785
  _DESCRIBEBINDINGRESPONSE._serialized_start=16787
  _DESCRIBEBINDINGRESPONSE._serialized_end=16858
  _DESCRIBEBINDINGRESULT._serialized_start=16860
  _DESCRIBEBINDINGRESULT._serialized_end=16925
  _MODIFYBINDINGREQUEST._serialized_start=16928
  _MODIFYBINDINGREQUEST._serialized_end=17162
  _MODIFYBINDINGRESPONSE._serialized_start=17164
  _MODIFYBINDINGRESPONSE._serialized_end=17233
  _MODIFYBINDINGRESULT._serialized_start=17235
  _MODIFYBINDINGRESULT._serialized_end=17256
  _DELETEBINDINGREQUEST._serialized_start=17259
  _DELETEBINDINGREQUEST._serialized_end=17444
  _DELETEBINDINGRESPONSE._serialized_start=17446
  _DELETEBINDINGRESPONSE._serialized_end=17515
  _DELETEBINDINGRESULT._serialized_start=17517
  _DELETEBINDINGRESULT._serialized_end=17538
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ydb._grpc.v4.protos import ydb_monitoring_pb2 as protos_dot_ydb__monitoring__pb2


class MonitoringServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SelfCheck = channel.unary_unary(
                '/Ydb.Monitoring.V1.MonitoringService/SelfCheck',
                request_serializer=protos_dot_ydb__monitoring__pb2.SelfCheckRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__monitoring__pb2.SelfCheckResponse.FromString,
                )
        self.NodeCheck = channel.unary_unary(
                '/Ydb.Monitoring.V1.MonitoringService/NodeCheck',
                request_serializer=protos_dot_ydb__monitoring__pb2.NodeCheckRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__monitoring__pb2.NodeCheckResponse.FromString,
                )


class MonitoringServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SelfCheck(self, request, context):
        """Gets the health status of the database.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NodeCheck(self, request, context):
        """Checks current node health
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MonitoringServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SelfCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.SelfCheck,
                    request_deserializer=protos_dot_ydb__monitoring__pb2.SelfCheckRequest.FromString,
                    response_serializer=protos_dot_ydb__monitoring__pb2.SelfCheckResponse.SerializeToString,
            ),
            'NodeCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.NodeCheck,
                    request_deserializer=protos_dot_ydb__monitoring__pb2.NodeCheckRequest.FromString,
                    response_serializer=protos_dot_ydb__monitoring__pb2.NodeCheckResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Ydb.Monitoring.V1.MonitoringService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MonitoringService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SelfCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Monitoring.V1.MonitoringService/SelfCheck',
            protos_dot_ydb__monitoring__pb2.SelfCheckRequest.SerializeToString,
            protos_dot_ydb__monitoring__pb2.SelfCheckResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NodeCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Monitoring.V1.MonitoringService/NodeCheck',
            protos_dot_ydb__monitoring__pb2.NodeCheckRequest.SerializeToString,
            protos_dot_ydb__monitoring__pb2.NodeCheckResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from ydb._grpc.v6.protos import ydb_scheme_pb2 as protos_dot_ydb__scheme__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in ydb_scheme_v1_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SchemeServiceStub(object):
    """Every YDB Database Instance has set of objects organized a tree.
    SchemeService provides some functionality to browse and modify
    this tree.

    SchemeService provides a generic tree functionality, to create specific
    objects like YDB Table or Persistent Queue use corresponding services.

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.MakeDirectory = channel.unary_unary(
                '/Ydb.Scheme.V1.SchemeService/MakeDirectory',
                request_serializer=protos_dot_ydb__scheme__pb2.MakeDirectoryRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__scheme__pb2.MakeDirectoryResponse.FromString,
                _registered_method=True)
        self.RemoveDirectory = channel.unary_unary(
                '/Ydb.Scheme.V1.SchemeService/RemoveDirectory',
                request_serializer=protos_dot_ydb__scheme__pb2.RemoveDirectoryRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__scheme__pb2.RemoveDirectoryResponse.FromString,
                _registered_method=True)
        self.ListDirectory = channel.unary_unary(
                '/Ydb.Scheme.V1.SchemeService/ListDirectory',
                request_serializer=protos_dot_ydb__scheme__pb2.ListDirectoryRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__scheme__pb2.ListDirectoryResponse.FromString,
                _registered_method=True)
        self.DescribePath = channel.unary_unary(
                '/Ydb.Scheme.V1.SchemeService/DescribePath',
                request_serializer=protos_dot_ydb__scheme__pb2.DescribePathRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__scheme__pb2.DescribePathResponse.FromString,
                _registered_method=True)
        self.ModifyPermissions = channel.unary_unary(
                '/Ydb.Scheme.V1.SchemeService/ModifyPermissions',
                request_serializer=protos_dot_ydb__scheme__pb2.ModifyPermissionsRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__scheme__pb2.ModifyPermissionsResponse.FromString,
                _registered_method=True)


class SchemeServiceServicer(object):
    """Every YDB Database Instance has set of objects organized a tree.
    SchemeService provides some functionality to browse and modify
    this tree.

    SchemeService provides a generic tree functionality, to create specific
    objects like YDB Table or Persistent Queue use corresponding services.

    """

    def MakeDirectory(self, request, context):
        """Make Directory.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveDirectory(self, request, context):
        """Remove Directory.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDirectory(self, request, context):
        """Returns information about given directory and objects inside it.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DescribePath(self, request, context):
        """Returns information about object with given path.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModifyPermissions(self, request, context):
        """Modify permissions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SchemeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'MakeDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.MakeDirectory,
                    request_deserializer=protos_dot_ydb__scheme__pb2.MakeDirectoryRequest.FromString,
                    response_serializer=protos_dot_ydb__scheme__pb2.MakeDirectoryResponse.SerializeToString,
            ),
            'RemoveDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveDirectory,
                    request_deserializer=protos_dot_ydb__scheme__pb2.RemoveDirectoryRequest.FromString,
                    response_serializer=protos_dot_ydb__scheme__pb2.RemoveDirectoryResponse.SerializeToString,
            ),
            'ListDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDirectory,
                    request_deserializer=protos_dot_ydb__scheme__pb2.ListDirectoryRequest.FromString,
                    response_serializer=protos_dot_ydb__scheme__pb2.ListDirectoryResponse.SerializeToString,
            ),
            'DescribePath': grpc.unary_unary_rpc_method_handler(
                    servicer.DescribePath,
                    request_deserializer=protos_dot_ydb__scheme__pb2.DescribePathRequest.FromString,
                    response_serializer=protos_dot_ydb__scheme__pb2.DescribePathResponse.SerializeToString,
            ),
            'ModifyPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.ModifyPermissions,
                    request_deserializer=protos_dot_ydb__scheme__pb2.ModifyPermissionsRequest.FromString,
                    response_serializer=protos_dot_ydb__scheme__pb2.ModifyPermissionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Ydb.Scheme.V1.SchemeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('Ydb.Scheme.V1.SchemeService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SchemeService(object):
    """Every YDB Database Instance has set of objects organized a tree.
    SchemeService provides some functionality to browse and modify
    this tree.

    SchemeService provides a generic tree functionality, to create specific
    objects like YDB Table or Persistent Queue use corresponding services.

    """

    @staticmethod
    def MakeDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Ydb.Scheme.V1.SchemeService/MakeDirectory',
            protos_dot_ydb__scheme__pb2.MakeDirectoryRequest.SerializeToString,
            protos_dot_ydb__scheme__pb2.MakeDirectoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemoveDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Ydb.Scheme.V1.SchemeService/RemoveDirectory',
            protos_dot_ydb__scheme__pb2.RemoveDirectoryRequest.SerializeToString,
            protos_dot_ydb__scheme__pb2.RemoveDirectoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Ydb.Scheme.V1.SchemeService/ListDirectory',
            protos_dot_ydb__scheme__pb2.ListDirectoryRequest.SerializeToString,
            protos_dot_ydb__scheme__pb2.ListDirectoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DescribePath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Ydb.Scheme.V1.SchemeService/DescribePath',
            protos_dot_ydb__scheme__pb2.DescribePathRequest.SerializeToString,
            protos_dot_ydb__scheme__pb2.DescribePathResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ModifyPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Ydb.Scheme.V1.SchemeService/ModifyPermissions',
            protos_dot_ydb__scheme__pb2.ModifyPermissionsRequest.SerializeToString,
            protos_dot_ydb__scheme__pb2.ModifyPermissionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb_rate_limiter_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_rate_limiter_pb2 as protos_dot_ydb__rate__limiter__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ydb_rate_limiter_v1.proto',
  package='Ydb.RateLimiter.V1',
  syntax='proto3',
  serialized_options=b'\n\036tech.ydb.proto.rate_limiter.v1B\017RateLimiterGrpcP\001Z:github.com/ydb-platform/ydb-go-genproto/Ydb_RateLimiter_V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19ydb_rate_limiter_v1.proto\x12\x12Ydb.RateLimiter.V1\x1a\x1dprotos/ydb_rate_limiter.proto2\xe3\x04\n\x12RateLimiterService\x12\x61\n\x0e\x43reateResource\x12&.Ydb.RateLimiter.CreateResourceRequest\x1a\'.Ydb.RateLimiter.CreateResourceResponse\x12^\n\rAlterResource\x12%.Ydb.RateLimiter.AlterResourceRequest\x1a&.Ydb.RateLimiter.AlterResourceResponse\x12[\n\x0c\x44ropResource\x12$.Ydb.RateLimiter.DropResourceRequest\x1a%.Ydb.RateLimiter.DropResourceResponse\x12^\n\rListResources\x12%.Ydb.RateLimiter.ListResourcesRequest\x1a&.Ydb.RateLimiter.ListResourcesResponse\x12g\n\x10\x44\x65scribeResource\x12(.Ydb.RateLimiter.DescribeResourceRequest\x1a).Ydb.RateLimiter.DescribeResourceResponse\x12\x64\n\x0f\x41\x63quireResource\x12\'.Ydb.RateLimiter.AcquireResourceRequest\x1a(.Ydb.RateLimiter.AcquireResourceResponseBo\n\x1etech.ydb.proto.rate_limiter.v1B\x0fRateLimiterGrpcP\x01Z:github.com/ydb-platform/ydb-go-genproto/Ydb_RateLimiter_V1b\x06proto3'
  ,
  dependencies=[protos_dot_ydb__rate__limiter__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_RATELIMITERSERVICE = _descriptor.ServiceDescriptor(
  name='RateLimiterService',
  full_name='Ydb.RateLimiter.V1.RateLimiterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=81,
  serialized_end=692,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateResource',
    full_name='Ydb.RateLimiter.V1.RateLimiterService.CreateResource',
    index=0,
    containing_service=None,
    input_type=protos_dot_ydb__rate__limiter__pb2._CREATERESOURCEREQUEST,
    output_type=protos_dot_ydb__rate__limiter__pb2._CREATERESOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AlterResource',
    full_name='Ydb.RateLimiter.V1.RateLimiterService.AlterResource',
    index=1,
    containing_service=None,
    input_type=protos_dot_ydb__rate__limiter__pb2._ALTERRESOURCEREQUEST,
    output_type=protos_dot_ydb__rate__limiter__pb2._ALTERRESOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DropResource',
    full_name='Ydb.RateLimiter.V1.RateLimiterService.DropResource',
    index=2,
    containing_service=None,
    input_type=protos_dot_ydb__rate__limiter__pb2._DROPRESOURCEREQUEST,
    output_type=protos_dot_ydb__rate__limiter__pb2._DROPRESOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListResources',
    full_name='Ydb.RateLimiter.V1.RateLimiterService.ListResources',
    index=3,
    containing_service=None,
    input_type=protos_dot_ydb__rate__limiter__pb2._LISTRESOURCESREQUEST,
    output_type=protos_dot_ydb__rate__limiter__pb2._LISTRESOURCESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeResource',
    full_name='Ydb.RateLimiter.V1.RateLimiterService.DescribeResource',
    index=4,
    containing_service=None,
    input_type=protos_dot_ydb__rate__limiter__pb2._DESCRIBERESOURCEREQUEST,
    output_type=protos_dot_ydb__rate__limiter__pb2._DESCRIBERESOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AcquireResource',
    full_name='Ydb.RateLimiter.V1.RateLimiterService.AcquireResource',
    index=5,
    containing_service=None,
    input_type=protos_dot_ydb__rate__limiter__pb2._ACQUIRERESOURCEREQUEST,
    output_type=protos_dot_ydb__rate__limiter__pb2._ACQUIRERESOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RATELIMITERSERVICE)

DESCRIPTOR.services_by_name['RateLimiterService'] = _RATELIMITERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
import os
from typing import Optional


def read_bytes(f):
    with open(f, "rb") as fr:
        return fr.read()


def load_ydb_root_certificate(path: Optional[str] = None):
    path = path if path is not None else os.getenv("YDB_SSL_ROOT_CERTIFICATES_FILE", None)
    if path is not None and os.path.exists(path):
        return read_bytes(path)
    return None



import pytest
from contextlib import suppress

import ydb.aio.iam


@pytest.mark.asyncio
async def test_tx_commit(driver, database):
    session = await driver.table_client.session().create()
    prepared = await session.prepare(
        "DECLARE $param as Int32;\n SELECT $param as value",
    )

    tx = session.transaction()
    await tx.execute(prepared, {"$param": 2})
    await tx.commit()
    await tx.commit()


@pytest.mark.asyncio
async def test_tx_rollback(driver, database):
    session = await driver.table_client.session().create()
    prepared = await session.prepare(
        "DECLARE $param as Int32;\n SELECT $param as value",
    )

    tx = session.transaction()
    await tx.execute(prepared, {"$param": 2})
    await tx.rollback()
    await tx.rollback()


@pytest.mark.asyncio
async def test_tx_begin(driver, database):
    session = await driver.table_client.session().create()
    await session.create()

    tx = session.transaction()
    await tx.begin()
    await tx.begin()
    await tx.rollback()


@pytest.mark.asyncio
async def test_credentials():
    credentials = ydb.aio.iam.MetadataUrlCredentials()
    raised = False
    try:
        await credentials.auth_metadata()
    except Exception:
        raised = True

    assert raised


@pytest.mark.asyncio
async def test_tx_snapshot_ro(driver, database):
    session = await driver.table_client.session().create()
    description = (
        ydb.TableDescription()
        .with_primary_keys("key")
        .with_columns(
            ydb.Column("key", ydb.OptionalType(ydb.PrimitiveType.Uint64)),
            ydb.Column("value", ydb.OptionalType(ydb.PrimitiveType.Uint64)),
        )
    )
    tb_name = f"{database}/test"
    with suppress(ydb.issues.SchemeError):
        await session.drop_table(tb_name)
    await session.create_table(tb_name, description)
    await session.transaction(ydb.SerializableReadWrite()).execute(
        """INSERT INTO `test` (`key`, `value`) VALUES (1, 1), (2, 2)""",
        commit_tx=True,
    )

    ro_tx = session.transaction(tx_mode=ydb.SnapshotReadOnly())
    data1 = await ro_tx.execute("SELECT value FROM `test` WHERE key = 1")

    await session.transaction(ydb.SerializableReadWrite()).execute(
        "UPDATE `test` SET value = value + 1", commit_tx=True
    )

    data2 = await ro_tx.execute("SELECT value FROM `test` WHERE key = 1")
    assert data1[0].rows == data2[0].rows == [{"value": 1}]

    await ro_tx.commit()

    ro_tx = session.transaction(tx_mode=ydb.SnapshotReadOnly())
    with pytest.raises(ydb.issues.GenericError) as exc_info:
        await ro_tx.execute("UPDATE `test` SET value = value + 1")
    assert "read only transaction" in exc_info.value.message

    data = await session.transaction(tx_mode=ydb.SnapshotReadOnly()).execute(
        "SELECT value FROM `test` WHERE key = 1",
        commit_tx=True,
    )
    assert data[0].rows == [{"value": 2}]


@pytest.mark.asyncio
async def test_split_transactions_deny_split_explicit_commit(driver, table_name):
    async with ydb.aio.SessionPool(driver, 1) as pool:

        async def check_transaction(s: ydb.aio.table.Session):
            async with s.transaction(allow_split_transactions=False) as tx:
                await tx.execute("INSERT INTO %s (id) VALUES (1)" % table_name)
                await tx.commit()

                with pytest.raises(RuntimeError):
                    await tx.execute("INSERT INTO %s (id) VALUES (2)" % table_name)

                await tx.commit()

            async with s.transaction() as tx:
                rs = await tx.execute("SELECT COUNT(*) as cnt FROM %s" % table_name)
                assert rs[0].rows[0].cnt == 1

        await pool.retry_operation(check_transaction)


@pytest.mark.asyncio
async def test_split_transactions_deny_split_flag_commit(driver, table_name):
    async with ydb.aio.SessionPool(driver, 1) as pool:

        async def check_transaction(s: ydb.aio.table.Session):
            async with s.transaction(allow_split_transactions=False) as tx:
                await tx.execute("INSERT INTO %s (id) VALUES (1)" % table_name, commit_tx=True)

                with pytest.raises(RuntimeError):
                    await tx.execute("INSERT INTO %s (id) VALUES (2)" % table_name)

                await tx.commit()

            async with s.transaction() as tx:
                rs = await tx.execute("SELECT COUNT(*) as cnt FROM %s" % table_name)
                assert rs[0].rows[0].cnt == 1

        await pool.retry_operation(check_transaction)


@pytest.mark.asyncio
async def test_split_transactions_allow_split(driver, table_name):
    async with ydb.aio.SessionPool(driver, 1) as pool:

        async def check_transaction(s: ydb.aio.table.Session):
            async with s.transaction(allow_split_transactions=True) as tx:
                await tx.execute("INSERT INTO %s (id) VALUES (1)" % table_name)
                await tx.commit()

                await tx.execute("INSERT INTO %s (id) VALUES (2)" % table_name)
                await tx.commit()

            async with s.transaction() as tx:
                rs = await tx.execute("SELECT COUNT(*) as cnt FROM %s" % table_name)
                assert rs[0].rows[0].cnt == 2

        await pool.retry_operation(check_transaction)


@pytest.mark.asyncio
async def test_split_transactions_default(driver, table_name):
    async with ydb.aio.SessionPool(driver, 1) as pool:

        async def check_transaction(s: ydb.aio.table.Session):
            async with s.transaction() as tx:
                await tx.execute("INSERT INTO %s (id) VALUES (1)" % table_name)
                await tx.commit()

                with pytest.raises(RuntimeError):
                    await tx.execute("INSERT INTO %s (id) VALUES (2)" % table_name)

                await tx.commit()

            async with s.transaction() as tx:
                rs = await tx.execute("SELECT COUNT(*) as cnt FROM %s" % table_name)
                assert rs[0].rows[0].cnt == 1

        await pool.retry_operation(check_transaction)


@pytest.mark.asyncio
async def test_truncated_response(driver, table_name, table_path):
    column_types = ydb.BulkUpsertColumns().add_column("id", ydb.PrimitiveType.Int64)

    rows = []

    rows_count = 1100
    for i in range(rows_count):
        rows.append({"id": i})

    await driver.table_client.bulk_upsert(table_path, rows, column_types)

    table_client = driver.table_client  # default table client with driver's settings
    s = table_client.session()
    await s.create()
    t = s.transaction()
    with pytest.raises(ydb.TruncatedResponseError):
        await t.execute("SELECT * FROM %s" % table_name)


@pytest.mark.asyncio
async def test_truncated_response_allow(driver, table_name, table_path):
    column_types = ydb.BulkUpsertColumns().add_column("id", ydb.PrimitiveType.Int64)

    rows = []

    rows_count = 1100
    for i in range(rows_count):
        rows.append({"id": i})

    await driver.table_client.bulk_upsert(table_path, rows, column_types)

    table_client = ydb.TableClient(driver, ydb.TableClientSettings().with_allow_truncated_result(True))
    s = table_client.session()
    await s.create()
    t = s.transaction()
    result = await t.execute("SELECT * FROM %s" % table_name)
    assert result[0].truncated
    assert len(result[0].rows) == 1000
